==> cognito-1.104.0-sources.jar: software/amazon/awscdk/services/cognito/UserPoolDomain.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Define a user pool domain.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.29.0 (build 41df200)", date = "2021-05-14T22:40:16.087Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.UserPoolDomain")
public class UserPoolDomain extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.cognito.IUserPoolDomain {

    protected UserPoolDomain(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected UserPoolDomain(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public UserPoolDomain(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolDomainProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a UserPoolDomain given its domain name.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param userPoolDomainName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.IUserPoolDomain fromDomainName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String userPoolDomainName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cognito.UserPoolDomain.class, "fromDomainName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.IUserPoolDomain.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(userPoolDomainName, "userPoolDomainName is required") });
    }

    /**
     * The URL to the hosted UI associated with this domain.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String baseUrl() {
        return software.amazon.jsii.Kernel.call(this, "baseUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The URL to the sign in page in this domain using a specific UserPoolClient.
     * <p>
     * @param client [disable-awslint:ref-via-interface] the user pool client that the UI will use to interact with the UserPool. This parameter is required.
     * @param options options to customize the behaviour of this method. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String signInUrl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient client, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.SignInUrlOptions options) {
        return software.amazon.jsii.Kernel.call(this, "signInUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(client, "client is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * The domain name of the CloudFront distribution associated with the user pool domain.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getCloudFrontDomainName() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontDomainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The domain that was specified to be created.
     * <p>
     * If <code>customDomain</code> was selected, this holds the full domain name that was specified.
     * If the <code>cognitoDomain</code> was used, it contains the prefix to the Cognito hosted domain.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getDomainName() {
        return software.amazon.jsii.Kernel.get(this, "domainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cognito.UserPoolDomain}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cognito.UserPoolDomain> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cognito.UserPoolDomainProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cognito.UserPoolDomainProps.Builder();
        }

        /**
         * Associate a cognito prefix domain with your user pool Either `customDomain` or `cognitoDomain` must be specified.
         * <p>
         * Default: - not set if `customDomain` is specified, otherwise, throws an error.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain-prefix.html
         * @param cognitoDomain Associate a cognito prefix domain with your user pool Either `customDomain` or `cognitoDomain` must be specified. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cognitoDomain(final software.amazon.awscdk.services.cognito.CognitoDomainOptions cognitoDomain) {
            this.props.cognitoDomain(cognitoDomain);
            return this;
        }

        /**
         * Associate a custom domain with your user pool Either `customDomain` or `cognitoDomain` must be specified.
         * <p>
         * Default: - not set if `cognitoDomain` is specified, otherwise, throws an error.
         * <p>
         * @return {@code this}
         * @see https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-add-custom-domain.html
         * @param customDomain Associate a custom domain with your user pool Either `customDomain` or `cognitoDomain` must be specified. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomain(final software.amazon.awscdk.services.cognito.CustomDomainOptions customDomain) {
            this.props.customDomain(customDomain);
            return this;
        }

        /**
         * The user pool to which this domain should be associated.
         * <p>
         * @return {@code this}
         * @param userPool The user pool to which this domain should be associated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPool(final software.amazon.awscdk.services.cognito.IUserPool userPool) {
            this.props.userPool(userPool);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cognito.UserPoolDomain}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cognito.UserPoolDomain build() {
            return new software.amazon.awscdk.services.cognito.UserPoolDomain(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}

==> cognito-1.173.0-sources.jar: software/amazon/awscdk/services/cognito/UserPoolDomain.java <==
package software.amazon.awscdk.services.cognito;

/**
 * Define a user pool domain.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * UserPool userpool = UserPool.Builder.create(this, "UserPool").build();
 * UserPoolClient client = userpool.addClient("Client", UserPoolClientOptions.builder()
 *         // ...
 *         .oAuth(OAuthSettings.builder()
 *                 .flows(OAuthFlows.builder()
 *                         .implicitCodeGrant(true)
 *                         .build())
 *                 .callbackUrls(List.of("https://myapp.com/home", "https://myapp.com/users"))
 *                 .build())
 *         .build());
 * UserPoolDomain domain = userpool.addDomain("Domain", UserPoolDomainOptions.builder().build());
 * String signInUrl = domain.signInUrl(client, SignInUrlOptions.builder()
 *         .redirectUri("https://myapp.com/home")
 *         .build());
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:33.221Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.cognito.$Module.class, fqn = "@aws-cdk/aws-cognito.UserPoolDomain")
public class UserPoolDomain extends software.amazon.awscdk.core.Resource implements software.amazon.awscdk.services.cognito.IUserPoolDomain {

    protected UserPoolDomain(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected UserPoolDomain(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param props This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public UserPoolDomain(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolDomainProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    /**
     * Import a UserPoolDomain given its domain name.
     * <p>
     * @param scope This parameter is required.
     * @param id This parameter is required.
     * @param userPoolDomainName This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.IUserPoolDomain fromDomainName(final @org.jetbrains.annotations.NotNull software.constructs.Construct scope, final @org.jetbrains.annotations.NotNull java.lang.String id, final @org.jetbrains.annotations.NotNull java.lang.String userPoolDomainName) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(software.amazon.awscdk.services.cognito.UserPoolDomain.class, "fromDomainName", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.cognito.IUserPoolDomain.class), new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(userPoolDomainName, "userPoolDomainName is required") });
    }

    /**
     * The URL to the hosted UI associated with this domain.
     * <p>
     * @param options options to customize baseUrl.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String baseUrl(final @org.jetbrains.annotations.Nullable software.amazon.awscdk.services.cognito.BaseUrlOptions options) {
        return software.amazon.jsii.Kernel.call(this, "baseUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { options });
    }

    /**
     * The URL to the hosted UI associated with this domain.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String baseUrl() {
        return software.amazon.jsii.Kernel.call(this, "baseUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The URL to the sign in page in this domain using a specific UserPoolClient.
     * <p>
     * @param client [disable-awslint:ref-via-interface] the user pool client that the UI will use to interact with the UserPool. This parameter is required.
     * @param options options to customize signInUrl. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String signInUrl(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.UserPoolClient client, final @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.cognito.SignInUrlOptions options) {
        return software.amazon.jsii.Kernel.call(this, "signInUrl", software.amazon.jsii.NativeType.forClass(java.lang.String.class), new Object[] { java.util.Objects.requireNonNull(client, "client is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * The domain name of the CloudFront distribution associated with the user pool domain.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getCloudFrontDomainName() {
        return software.amazon.jsii.Kernel.get(this, "cloudFrontDomainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * The domain that was specified to be created.
     * <p>
     * If <code>customDomain</code> was selected, this holds the full domain name that was specified.
     * If the <code>cognitoDomain</code> was used, it contains the prefix to the Cognito hosted domain.
     */
    @Override
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getDomainName() {
        return software.amazon.jsii.Kernel.get(this, "domainName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * A fluent builder for {@link software.amazon.awscdk.services.cognito.UserPoolDomain}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<software.amazon.awscdk.services.cognito.UserPoolDomain> {
        /**
         * @return a new instance of {@link Builder}.
         * @param scope This parameter is required.
         * @param id This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public static Builder create(final software.constructs.Construct scope, final java.lang.String id) {
            return new Builder(scope, id);
        }

        private final software.constructs.Construct scope;
        private final java.lang.String id;
        private final software.amazon.awscdk.services.cognito.UserPoolDomainProps.Builder props;

        private Builder(final software.constructs.Construct scope, final java.lang.String id) {
            this.scope = scope;
            this.id = id;
            this.props = new software.amazon.awscdk.services.cognito.UserPoolDomainProps.Builder();
        }

        /**
         * Associate a cognito prefix domain with your user pool Either `customDomain` or `cognitoDomain` must be specified.
         * <p>
         * Default: - not set if `customDomain` is specified, otherwise, throws an error.
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain-prefix.html">https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-assign-domain-prefix.html</a>
         * @param cognitoDomain Associate a cognito prefix domain with your user pool Either `customDomain` or `cognitoDomain` must be specified. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder cognitoDomain(final software.amazon.awscdk.services.cognito.CognitoDomainOptions cognitoDomain) {
            this.props.cognitoDomain(cognitoDomain);
            return this;
        }

        /**
         * Associate a custom domain with your user pool Either `customDomain` or `cognitoDomain` must be specified.
         * <p>
         * Default: - not set if `cognitoDomain` is specified, otherwise, throws an error.
         * <p>
         * @return {@code this}
         * @see <a href="https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-add-custom-domain.html">https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-user-pools-add-custom-domain.html</a>
         * @param customDomain Associate a custom domain with your user pool Either `customDomain` or `cognitoDomain` must be specified. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder customDomain(final software.amazon.awscdk.services.cognito.CustomDomainOptions customDomain) {
            this.props.customDomain(customDomain);
            return this;
        }

        /**
         * The user pool to which this domain should be associated.
         * <p>
         * @return {@code this}
         * @param userPool The user pool to which this domain should be associated. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder userPool(final software.amazon.awscdk.services.cognito.IUserPool userPool) {
            this.props.userPool(userPool);
            return this;
        }

        /**
         * @returns a newly built instance of {@link software.amazon.awscdk.services.cognito.UserPoolDomain}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public software.amazon.awscdk.services.cognito.UserPoolDomain build() {
            return new software.amazon.awscdk.services.cognito.UserPoolDomain(
                this.scope,
                this.id,
                this.props.build()
            );
        }
    }
}
